@@ -40,7 +40,6 @@ class VideoStorage(Device):
         f = File(self)
         f.is_local = True
         f.path = "/" + urlquote.quote(folder_name, "")
-        f.can_skip = True
         f.mimetype = f.DIRECTORY
         f.resource = ""
         f.name = folder_name
@@ -48,7 +47,6 @@ class VideoStorage(Device):
         f.acoustic_name = "Folder: " + f.name
         #f.info = "%d items" % len(self.__folders.get(folder_name, []))
         f.folder_flags = f.ITEMS_ENQUEUEABLE | \
-                         f.ITEMS_SKIPPABLE | \
                          f.ITEMS_COMPACT
 
         return f
@@ -63,7 +61,6 @@ class VideoStorage(Device):
         if (len_parts == 0):
             f = File(self)
             f.is_local = True
-            f.can_skip = True
             f.path = "/"
             f.mimetype = f.DEVICE_ROOT
             f.resource = ""
