@@ -21,7 +21,7 @@ _LANDSCAPE_ARRANGEMENT = """
       <widget name="btn_nav" x1="0" y1="-64" x2="64" y2="100%"/>
       <widget name="toolbar" x1="-80" y1="0" x2="100%" y2="100%"/>
 
-      <widget name="screen" x1="40" y1="0" x2="-80" y2="-64"/>
+      <widget name="screen" x1="40" y1="4" x2="-84" y2="-64"/>
       <widget name="progress" x1="90" y1="-50" x2="-90" y2="-10"/>
       <widget name="slider" x1="0" y1="0" x2="40" y2="-64"/>
     </if-visible>
@@ -211,6 +211,12 @@ class VideoPlayer(Player):
                 self.emit_message(msgs.MEDIA_EV_EOF)
                 self.emit_message(msgs.MEDIA_ACT_NEXT)
 
+            elif (status == self.__player.STATUS_CONNECTING):
+                self.__progress.set_message("Connecting")
+
+            elif (status == self.__player.STATUS_BUFFERING):
+                self.__progress.set_message("Buffering")
+                
 
     def __on_update_position(self, ctx_id, pos, total):
     
@@ -346,9 +352,17 @@ class VideoPlayer(Player):
                           f, logging.stacktrace())
 
 
+    def handle_MEDIA_ACT_PLAY(self):
+    
+        if (self.__player and self.is_enabled()):
+            if (not self.__is_playing):
+                self.__wait_for_dsp()
+            self.__player.play()
+
+
     def handle_MEDIA_ACT_PAUSE(self):
     
-        if (self.__player):
+        if (self.__player and self.is_enabled()):
             if (not self.__is_playing):
                 self.__wait_for_dsp()
             self.__player.pause()
@@ -357,7 +371,7 @@ class VideoPlayer(Player):
 
     def handle_MEDIA_ACT_STOP(self):
     
-        if (self.__player):
+        if (self.__player and self.is_enabled()):
             self.__player.stop()
 
 
