@@ -30,8 +30,7 @@ _VIDEO_SEARCH = "http://gdata.youtube.com/feeds/api/videos/" \
                 "?start-index=%d&max-results=%d&vq=%s"
 _VIDEO_WATCH = _YT + "/watch?v=%s"
 _VIDEO_FLV = _YT + "/get_video?video_id=%s"
-_STD_FEEDS = "http://gdata.youtube.com/feeds/standardfeeds/" \
-             "%s?start-index=%d&max-results=%d"
+_STD_FEEDS = "http://gdata.youtube.com/feeds/standardfeeds/"
 
 _XMLNS_ATOM = "http://www.w3.org/2005/Atom"
 _XMLNS_MRSS = "http://search.yahoo.com/mrss/"
@@ -40,12 +39,26 @@ _XMLNS_GOOGLE = "http://schemas.google.com/g/2005"
 _XMLNS_YT = "http://gdata.youtube.com/schemas/2007"
 _XMLNS_APP = "http://purl.org/atom/app#"
 
+_VIDEOS_API = "http://gdata.youtube.com/feeds/api/videos"
+_SEARCH_PARAMS = "?start-index=%d&max-results=%d"
+_SEARCH_PARAMS2 = "&start-index=%d&max-results=%d"
+_CATEGORIES = {
+    "recently_featured": _STD_FEEDS + "recently_featured" + _SEARCH_PARAMS,
+    "most_viewed":       _STD_FEEDS + "most_viewed" + _SEARCH_PARAMS,
+    "most_popular":      _STD_FEEDS + "most_popular" + _SEARCH_PARAMS,
+    "top_rated":         _STD_FEEDS + "top_rated?time=today" + _SEARCH_PARAMS2,
+    "watch_on_mobile":   _STD_FEEDS + "watch_on_mobile" + _SEARCH_PARAMS,
+    "music":             _VIDEOS_API + "?category=Music&orderby=published" + _SEARCH_PARAMS2,
+    "movie":             _VIDEOS_API + "?category=Movies&orderby=published" + _SEARCH_PARAMS2,
+    "news":              _VIDEOS_API + "?category=News&orderby=published" + _SEARCH_PARAMS2
+}
+
 _REGION_BLOCKED = "region blocked"
 
 _SEARCH_CACHE_DIR = os.path.join(values.USER_DIR, "youtube/search-cache")
 _VIDEO_FOLDER = "Saved Videos"
 
-_PAGE_SIZE = 25
+_PAGE_SIZE = 50
 
 
 _STAR_CHAR = u"\u2606"
@@ -196,10 +209,17 @@ class YouTube(Device):
 
     def __ls_menu(self, cb, *args):
     
-        for name, category in [("Search", "video"),
-                               ("Featured", "recently_featured"),
-                               ("Most Viewed", "most_viewed"),
-                               ("Top Rated", "top_rated")]:            
+        for name, category, icon in [
+            ("Search", "video", theme.youtube_search),
+            ("Recently Featured", "recently_featured", None),
+            ("Today's Top Rated", "top_rated", None),
+            ("Most Viewed", "most_viewed", None),
+            ("Most Popular", "most_popular", None),
+            ("Music", "music", None),
+            ("Movies", "movie", None),
+            ("News", "news", None),
+            ("For Mobile Phones", "watch_on_mobile", None)
+        ]:
             item = File(self)
             query = ""
             idx = 0
@@ -207,6 +227,8 @@ class YouTube(Device):
             item.resource = item.path
             item.name = name
             item.mimetype = File.DIRECTORY
+            if (icon):
+                item.icon = icon.get_path()
             
             cb(item, *args)
         #end for
@@ -260,7 +282,6 @@ class YouTube(Device):
     
         def on_receive_node(node):
             if (node.get_name() == "{%s}entry" % _XMLNS_ATOM):
-                print node
                 f = self.__make_video_from_node(node)
                 cb(f, *args)
 
@@ -368,6 +389,9 @@ class YouTube(Device):
         
         
     def __make_video(self, path):
+        """
+        Creates a video file object from the given path.
+        """
     
         prefix, title, info, video_id, thumbnail_url = File.unpack_path(path)
         
@@ -388,7 +412,6 @@ class YouTube(Device):
         return f
         
 
-
     def __parse_rating(self, node):
         """
         Parses the rating node and returns a string representation.
@@ -428,42 +451,41 @@ class YouTube(Device):
                 return
                 
             url = _VIDEO_SEARCH % (1, 1, query)
-            print "URL", url
+            #print "URL", url
             Downloader(url, self.__on_receive_xml, [""], "video", query, True, cb, *args)
             
         else:
             url = _VIDEO_SEARCH % (start_index, _PAGE_SIZE, query)
-            print "URL", url
+            #print "URL", url
             Downloader(url, self.__on_receive_xml, [""], "video", query, False, cb, *args)
         #end if
 
        
-
-    def __generic_search(self, category, cb, args, start_index):
+    def __category_search(self, category, cb, args, start_index):
 
         start_index = int(start_index)
         
-        print category, start_index
+        #print category, start_index
         if (start_index == 0):
-            url = _STD_FEEDS % (category, 1, 1)
+            url = _CATEGORIES[category] % (1, 1)
             Downloader(url, self.__on_receive_xml, [""], category, "", True, cb, *args)
         else:
-            url = _STD_FEEDS % (category, start_index, _PAGE_SIZE)
+            url = _CATEGORIES[category] % (start_index, _PAGE_SIZE)
             Downloader(url, self.__on_receive_xml, [""], category, "", False, cb, *args)
 
-   
 
     def __ls_search(self, path, cb, *args):
 
         prefix, name, category, query, idx = File.unpack_path(path)
-        print path
-        print prefix, name, category, query, idx
+        #print path
+        #print prefix, name, category, query, idx
         if (category == "video"):
             self.__video_search(cb, args, query, idx)
         else:
-            self.__generic_search(category, cb, args, idx)
+            self.__category_search(category, cb, args, idx)
 
 
+    """
     def __ls_local_videos(self, cb, *args):
     
         videos = []
@@ -493,8 +515,9 @@ class YouTube(Device):
             self.__items.append(f)
         #end for
         cb(None, *args)
-        
-        
+    """ 
+
+ 
     def get_contents(self, folder, begin_at, end_at, cb, *args):
 
         if (begin_at > 0):
@@ -512,13 +535,13 @@ class YouTube(Device):
         elif (path.startswith("/search")):
             self.__ls_search(path, cb, *args)
             
-        elif (path.startswith("/local")):
-            self.__ls_local_videos(cb, *args)
+        #elif (path.startswith("/local")):
+        #    self.__ls_local_videos(cb, *args)
            
            
     def __get_video(self, f):
         """
-        Returns the video URL and a valid filename.
+        Returns the video URL.
         """
 
         if (f.resource == _REGION_BLOCKED):
@@ -553,72 +576,53 @@ class YouTube(Device):
         else:
             ext = ".flv"
             
-        #self.emit_message(msgs.UI_ACT_HIDE_MESSAGE)
         logging.info("found FLV: %s", flv)
 
-        if (self.__flv_downloader):
-            self.__flv_downloader.cancel()
-
-        cache_folder = config.get_cache_folder()
-        flv_path = os.path.join(cache_folder, ".tube.flv")
-        keep_path = self.__make_filename(f.name, ext)
-
-        return (flv + "&ext=" + ext, keep_path)
+        return flv + "&ext=" + ext
 
 
     def get_resource(self, f):
 
-        """    
-        def on_dload(d, a, t, flv_path, keep_path):
+        #"""    
+        def on_dload(d, a, t):
             if (d):
                 self.emit_message(msgs.MEDIA_EV_DOWNLOAD_PROGRESS, f, a, t)
                 #print "%d / %d         " % (a, t)
                 #print gobject.main_depth()
                 #if (gobject.main_depth() < 3): 
-                gtk.main_iteration(False)
+                #gtk.main_iteration(False)
                 
             else:
                 self.emit_message(msgs.MEDIA_EV_DOWNLOAD_PROGRESS, f, a, t)
-                if (self.__keep_video):
-                    keep_dir = os.path.dirname(keep_path)
-                    if (not os.path.exists(keep_dir)):
-                        try:
-                            os.makedirs(os.path.dirname(keep_path))
-                        except:
-                            pass
-                    #end if
-                    try:
-                        os.rename(flv_path, keep_path)
-                    except:
-                        logging.error("could not save video '%s'\n%s" \
-                                      % (keep_path, logging.stacktrace()))
-                    # copy thumbnail
-                    self.__copy_thumbnail(f, keep_path)
-                #end if
             #end if
-        """
+        #"""
 
-        """
-        # handle locally saved videos
-        if (f.resource.startswith("/")): return f.resource
-        """
+        url = self.__get_video(f)
 
-        url, nil = self.__get_video(f)
-        return url
+        if (self.__flv_downloader):
+            self.__flv_downloader.cancel()
 
-        """
-        self.__flv_downloader = FileDownloader(flv, flv_path, on_dload,
-                                               flv_path, keep_path)
+        if (platforms.MAEMO4):
+            cache_folder = config.get_cache_folder()
+            try:
+                if (not os.path.exists(cache_folder)):
+                    os.mkdir(cache_folder)
+            except:
+                return ""
+            flv_path = os.path.join(cache_folder, ".tube.flv")
+
+            self.__flv_downloader = FileDownloader(url, flv_path, on_dload)
         
-        # we don't give the downloaded file directly to the player because
-        # if we did so, the player would fall off the video if it reached
-        # the end of file before it was downloaded completely.
-        # instead we serve it on a webserver to make the player wait for
-        # more if the download rate is too low
-        self.__fileserver.allow(flv_path, "/" + f.resource + ".flv")
+            # we don't give the downloaded file directly to the player because
+            # if we did so, the player would fall off the video if it reached
+            # the end of file before it was downloaded completely.
+            # instead we serve it on a webserver to make the player wait for
+            # more if the download rate is too low
+            self.__fileserver.allow(flv_path, "/" + f.resource + ".flv")
         
-        return self.__fileserver.get_location() + "/" + f.resource + ".flv"
-        """
+            return self.__fileserver.get_location() + "/" + f.resource + ".flv"
+        else:
+            return url
 
 
     def __ask_for_quality(self, fmts):
@@ -636,12 +640,14 @@ class YouTube(Device):
 
     def __on_download(self, folder, f):
 
-        url, filename = self.__get_video(f)
+        url = self.__get_video(f)
         if (not url):
             return
             
         dlg = FileDialog(FileDialog.TYPE_SAVE, "Save Video")
-        dlg.set_filename(f.name + mimetypes.mimetype_to_ext(f.mimetype))
+        name = File.make_safe_name(f.name)
+        ext = mimetypes.mimetype_to_ext(f.mimetype)
+        dlg.set_filename(name + ext)
         dlg.run()
         
         destination = dlg.get_filename()
@@ -659,26 +665,6 @@ class YouTube(Device):
         return actions
 
 
-    def delete_file(self, folder, idx):
-        """
-        Deletes the given file.
-        """
-
-        pass
-        """
-        f = self.__items[idx]
-        response = dialogs.question("Remove",
-                                    u"Remove video\n\xbb%s\xab?" % f.name)
-        if (response == 0):
-            try:
-                os.unlink(f.resource)
-            except:
-                pass
-        
-        self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, self.__current_folder)
-        """
-
-
     def __make_filename(self, name, ext):
         """
         Creates a (hopefully) valid filename from the given name.
@@ -692,14 +678,5 @@ class YouTube(Device):
         for a, b in replace_map:
             name = name.replace(a, b)
 
-        #return urlquote.quote(name, " ") + ".flv"
         return name + ext
 
-
-    def __copy_thumbnail(self, f1, path):
-    
-        f2 = File(self)
-        f2.path = "/local" + path
-
-        self.call_service(msgs.MEDIASCANNER_SVC_COPY_THUMBNAIL, f1, f2)
-
