@@ -7,6 +7,8 @@ from HTTPConnection import HTTPConnection, parse_addr
 from utils import logging
 
 import gtk
+import gobject
+import time
 
 
 class Downloader(HTTPConnection):
@@ -59,6 +61,9 @@ class Downloader(HTTPConnection):
             #self.putheader("Connection", "close")
             self.endheaders()
             self.send("", self.__on_receive_data, cb, args)
-        
-        while (gtk.events_pending()):
+
+        # try to avoid starvation of GTK for high bandwidths
+        then = time.time() + 0.1
+        while (gtk.events_pending() and time.time() < then):
             gtk.main_iteration(False)
+
