@@ -13,7 +13,7 @@ import socket
 import urlparse
 
 
-_BUFFER_SIZE = 4096
+_BUFFER_SIZE = 65536
 _CONNECTION_TIMEOUT = 30000
 
     
@@ -411,7 +411,7 @@ class HTTPConnection(object):
 
     def __finish_download(self, resp):
 
-        if (self.__close_connection):
+        if (self.__close_connection and self.__sock):
             self.__sock.close()
             self.__sock = None
             
