@@ -102,6 +102,12 @@ class File(object):
         @since: 0.96
         """
 
+        self.message = ""
+        """
+        text message displayed in the browser
+        @since: 2010.06.18
+        """
+
         self.index = 0
         """
         index number that can be used for sorting
@@ -327,17 +333,18 @@ class File(object):
         """
         
         return self.__device.get_file_actions(self, f)
-       
-        
-    """
+
+
     def get_children(self):
-        ""
+        """
         Returns a list of children of this folder.
         @since: 0.96
-        @deprecated: L{get_children_async} should be used instead
         
         @return: list of File objects
-        ""
+        """
+    
+        import gtk
+        import gobject
     
         def collector(f):
             if (f):
@@ -349,12 +356,11 @@ class File(object):
     
         finished = [False]
         collection = []
-        self.get_children_async(collector)
+        self.get_contents(0, 0, collector)
         while (not finished[0]):
             gtk.main_iteration(True)
     
         return collection
-    """
     
 
     def get_children_async(self, cb, *args):
@@ -437,6 +443,29 @@ class File(object):
         self.__device.shift_file(self, pos, amount)
         
         
+    @staticmethod
+    def make_safe_name(name):
+        """
+        Returns a filename-safe version of the given name.
+        @since: 2010.06.15
+        
+        @param name: a string
+        @return: a string that can be safely used for a filename
+        """
+
+        replace_map = [("/", "-"),
+                       ("!", ""),
+                       ("*", "+"),
+                       ("?", ""),
+                       ("\\", "-"),
+                       (":", "-")]
+                       
+        for a, b in replace_map:
+            name = name.replace(a, b)
+
+        return name
+
+        
     @staticmethod
     def pack_path(prefix, *items):
         """
