@@ -111,6 +111,9 @@ class Window(Widget):
                 self.__window.vbox.get_children()[0].hide()
             else:
                 self.__window = gtk.Dialog()
+                # hide some ugly separator :)
+                self.__window.vbox.get_children()[0].hide()
+
 
         # title bar on some platforms
         if (not platforms.MAEMO5 and wtype != self.TYPE_DIALOG):
@@ -152,7 +155,7 @@ class Window(Widget):
 
         if (platforms.MAEMO5):
             if (wtype == self.TYPE_TOPLEVEL):
-                self.__set_portrait_property("_HILDON_PORTRAIT_MODE_SUPPORT", 1)
+                pass #self.__set_portrait_property("_HILDON_PORTRAIT_MODE_SUPPORT", 1)
             else:
                 self.__set_portrait_property("_HILDON_PORTRAIT_MODE_SUPPORT", 1)
 
@@ -267,6 +270,11 @@ class Window(Widget):
 
 
     def __check_exclusive(self):
+        """
+        Checks for the presence of an exclusive window and hides it, if there
+        is one. This allows us to hide dialogs by clicking outside on platforms
+        where the window manager doesn't provide this feature already.
+        """
     
         if (self.__exclusive_window[0] and
             self.__exclusive_window[0] != self):
@@ -404,15 +412,16 @@ class Window(Widget):
     def _update_flag(self, flag, value):
 
         if (flag == windowflags.FULLSCREEN):
-            if (platforms.MAEMO4 or platforms.MEEGO_NETBOOK):
-                if (self.__title_bar):
-                    self.__title_bar.set_visible(not value)
-                    self.render()
-            else:
+            if (platforms.MAEMO5):
                 if (value):
                     self.__window.fullscreen()
                 else:
                     self.__window.unfullscreen()
+            else:
+                if (self.__title_bar):
+                    self.__title_bar.set_visible(not value)
+                    self.render()
+            
         
         elif (flag == windowflags.ASR):
             if (platforms.MAEMO5):
@@ -649,6 +658,6 @@ class Window(Widget):
             gtk.main_iteration(True)
         #end while
 
-        if (self.__exclusive_window[0] == self):
-            self.__exclusive_window[0] = None
-
+        #if (self.__exclusive_window[0] == self):
+        #    self.__exclusive_window[0] = None
+        gobject.timeout_add(0, self.destroy)
